package com.cultural.heritage.controller.order;

import com.cultural.heritage.common.BaseResponse;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.common.ResultUtils;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.exception.ThrowUtils;
import com.cultural.heritage.model.dto.order.OrderAddRequest;
import com.cultural.heritage.model.entity.Order;
import com.cultural.heritage.service.order.OrderService;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.weaver.ast.Or;
import org.springframework.beans.BeanUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@RestController
@RequestMapping("/order")
@Slf4j
@Tag(name = "订单接口")
public class OrderController {

    @Resource
    private OrderService orderService;


    /**
     * 用户创建订单
     * @param orderAddRequest  订单创建请求体
     * @return  是否创建成功
     */
    @PostMapping("/add")
    public BaseResponse<Boolean> addOrder(@RequestBody OrderAddRequest orderAddRequest) {
        if (orderAddRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Order order = new Order();
        BeanUtils.copyProperties(orderAddRequest, order);
        boolean save = orderService.save(order);
        ThrowUtils.throwIf(!save, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true);
    }

    /**
     * 查询所有订单
     * @return
     */
    @PostMapping("/list")
    public BaseResponse<List<Order>> listOrder() {
        List<Order> list = orderService.list();
        return ResultUtils.success(list);
    }
}
